@@ -106,43 +106,39 @@ class FifoQueue(Base):
         """Pop a request"""
         data = None
         bucket = None
-        if timeout > 0:
-            # 一秒钟去看看有没有数据
-            while timeout > 0:
-                # 先pop最高优先级桶内的request
-                prio_bucket = self.bucket_size + 1
-                bucket_key = self.key + "_" + str(prio_bucket)
-                logger.debug("[pop] bucket_key is {} start".format(bucket_key))
-                data = self.server.rpop(bucket_key)
-                if data:
-                    return self._decode_request(data)
 
-                bucket_count_map = self.server.hgetall(self.exist_bucket_key)
-                # 遍历dict
-                if bucket_count_map:
-                    for entry in bucket_count_map:
-                        if int(bucket_count_map[entry].decode('utf-8')) > 0:
-                            # 拿到有效桶号
-                            bucket = entry
-                            break
+        # 先pop最高优先级桶内的request
+        prio_bucket = self.bucket_size + 1
+        bucket_key = self.key + "_" + str(prio_bucket)
+        logger.debug("[pop] bucket_key is {} start".format(bucket_key))
+        data = self.server.rpop(bucket_key)
+        if data:
+            return self._decode_request(data)
 
-                if bucket:
-                    bucket_key = self.key + "_" + bucket.decode("utf-8")
-                    logger.info("[hgetall-bucket] bucket key is {}, bucket is {}".format(self.exist_bucket_key, bucket_key))
-                    data = self.server.rpop(bucket_key)
-                    if data:
-                        logger.info("[rpop] key is {}, data is {}".format(self.key + "_" + bucket.decode("utf-8"),
-                                                                           self._decode_request(data)))
-                        self.server.hincrby(self.exist_bucket_key, bucket, -1)
-                        logger.info("[hincrby] minus 1 for {}".format(bucket))
+        bucket_count_map = self.server.hgetall(self.exist_bucket_key)
+        # 遍历dict
+        if bucket_count_map:
+            for entry in bucket_count_map:
+                if int(bucket_count_map[entry].decode('utf-8')) > 0:
+                    # 拿到有效桶号
+                    bucket = entry
+                    break
 
-                        if isinstance(data, tuple):
-                            data = data[1]
-                if data:
-                    logger.info("pop url is {}".format(self._decode_request(data).url))
-                    return self._decode_request(data)
-                time.sleep(1)
-                timeout = timeout - 1
+        if bucket:
+            bucket_key = self.key + "_" + bucket.decode("utf-8")
+            logger.info("[hgetall-bucket] bucket key is {}, bucket is {}".format(self.exist_bucket_key, bucket_key))
+            data = self.server.rpop(bucket_key)
+            if data:
+                logger.info("[rpop] key is {}, data is {}".format(self.key + "_" + bucket.decode("utf-8"),
+                                                                   self._decode_request(data)))
+                self.server.hincrby(self.exist_bucket_key, bucket, -1)
+                logger.info("[hincrby] minus 1 for {}".format(bucket))
+
+                if isinstance(data, tuple):
+                    data = data[1]
+        if data:
+            logger.info("pop url is {}".format(self._decode_request(data).url))
+            return self._decode_request(data)
 
 
 class PriorityQueue(Base):
